{ pkgs
, config,
... }:

let
  unstablepkgs = import <channels-nixos-unstable> { config = config.nixpkgs.config; };

in {
  imports = [
    ../profiles/common.nix
    ../profiles/qtile-desktop.nix
    ../profiles/dotfiles.nix
    ../programs/emacs.nix
    ../programs/firefox.nix
    ../programs/chromium.nix
    ../programs/homeshick.nix
    ../programs/libreoffice.nix
    ../programs/neovim.nix
    ../programs/pass.nix
    ../programs/zsh.nix
  ];

  nixpkgs.config = {
    pidgin = {
      openssl = true;
      gnutls = true;
    };

    android_sdk.accept_license = true;

    packageOverrides = pkgs: with pkgs; {
      myPython36 = python36Full.withPackages (ps: with ps; [
        pylint pep8 yapf flake8
        # autopep8 (broken)
        # pylint (broken)
        ipython
        llfuse
        dugong
        defusedxml
        wheel
        pip
        virtualenv
        pypi2nix
        cffi
        pyopenssl
        urllib3
        mistune

        flask

        pyaml
      ] ++ [
        pkgs.libffi
      ]);
    };
  };

  home.sessionVariables = {
  };


  home.packages =
    [] ++ (with pkgs; [
      # Nix package related tools
      patchelf
      nix-index
      nix-prefetch-scripts

      # Version Control Systems
      gitless

      # Process/System Administration
      htop
      gnome3.gnome-tweak-tool
      xorg.xhost
      dmidecode
      python36Packages.glances
      evtest

      # Archive Managers
      sshfsFuse
      xarchive
      p7zip
      zip
      unzip
      gzip
      lzop

      # Password Management
      gnome3.gnome_keyring
      gnome3.seahorse

      # Remote Control Tools
      remmina
      freerdp
      x2goclient

      # Network Tools
      openvpn
      tcpdump
      iftop
      iperf
      bind
      socat

      # samba
      iptables
      nftables
      wireshark

      # Code Editors
      xclip
      xsel
      unstablepkgs.vscode

      # Image/Graphic/Design Tools
      gnome3.eog
      gimp
      inkscape

      # Misc Development Tools
      qrcode
      jq
      cdrtools

      # Document Processing and Management
      zathura

      # File Synchronzation
      rsync

      # Filesystem Tools
      ntfs3g
      ddrescue
      ncdu
      unstablepkgs.woeusb
      unetbootin
      pcmanfm
      hdparm
      testdisk
      python27Packages.binwalk
      gptfdisk

      androidsdk

      ## Python
      myPython36

      busyboxStatic

      # Virtualization
      virtmanager
  ]);
}
