{ config
, pkgs
, lib
, ...
}:

{
  nix.binaryCachePublicKeys = [
    # "hydra.nixos.org-1:CNHJZBh9K4tP3EKF6FkkgeVYsS3ohTl+oS0Qa8bezVs="
  ];
  nix.binaryCaches = [
    "https://cache.nixos.org"
    # "https://hydra.nixos.org"
  ];
  nix.trustedBinaryCaches = [
    "https://cache.nixos.org"
    # "https://hydra.nixos.org"
  ];

  nix.daemonNiceLevel = lib.mkDefault 19;
  nix.daemonIONiceLevel = lib.mkDefault 7;
  nix.maxJobs = lib.mkDefault 3;
  nix.buildCores = lib.mkDefault 3;
  nix.useSandbox = true;

  environment.etc."lvm/lvm.conf".text = ''
    devices {
      issue_discards = 1
    }
  '';

  # Fonts, I18N, Date ...
  fonts = {
    enableCoreFonts = true;
  };

  i18n = {
    consoleFont = "lat9w-16";
    defaultLocale = "en_US.UTF-8";
  };
  time.timeZone = "Europe/Berlin";
  services.gpm.enable = true;

  services.packagekit.enable = true;
  services.openssh.enable = true;
  networking.firewall.enable = true;

  # Activation scripts for impure set up of paths in /
  system.activationScripts.bin = ''
    echo "setting up /bin..."
    mkdir -p /bin
    ln -sfT ${pkgs.bash}/bin/bash /bin/.bash
    mv -Tf /bin/.bash /bin/bash
  '';
  system.activationScripts.etcX11sessinos = ''
    echo "setting up /etc/X11/sessions..."
    mkdir -p /etc/X11
    ln -sfT ${config.services.xserver.displayManager.session.desktops} /etc/X11/.sessions
    mv -Tf /etc/X11/.sessions /etc/X11/sessions
  '';
  system.activationScripts.lib64 = ''
    echo "setting up /lib64..."
    mkdir -p /lib64
    ln -sfT ${pkgs.stdenv.glibc}/lib/ld-linux-x86-64.so.2 /lib64/.ld-linux-x86-64.so.2
    mv -Tf /lib64/.ld-linux-x86-64.so.2 /lib64/ld-linux-x86-64.so.2
  '';

  programs.zsh.enable = true;
  users.defaultUserShell = pkgs.zsh;
  environment.pathsToLink = [ "/share/zsh" ];
}
